@@ -699,8 +699,6 @@ class PipelinedBartForConditionalGeneration(
         """
         super().parallelize()
 
-        layer_ipu = get_layer_ipu(self.ipu_config.layers_per_ipu)
-
         logger.info("-------------------- Device Allocation --------------------")
         logger.info("Embedding  --> IPU 0")
 
@@ -729,6 +727,8 @@ class PipelinedBartForConditionalGeneration(
             self.model.encoder.layernorm_embedding, "Embedding", ipu_id=0
         )
 
+        number_of_layers = len(self.model.encoder.layers) + len(self.model.decoder.layers)
+        layer_ipu = get_layer_ipu(self.ipu_config.layers_per_ipu, number_of_layers)
         for index, layer in enumerate(self.model.encoder.layers):
             ipu = layer_ipu[index]
             if self.ipu_config.recompute_checkpoint_every_layer and index != self.config.num_hidden_layers - 1:
@@ -863,8 +863,8 @@ class PipelinedBartForSequenceClassification(BartForSequenceClassification, Pipe
         self.model.encoder.layernorm_embedding = poptorch.BeginBlock(
             self.model.encoder.layernorm_embedding, "Embedding", ipu_id=0
         )
-
-        layer_ipu = get_layer_ipu(self.ipu_config.layers_per_ipu)
+        number_of_layers = len(self.model.encoder.layers) + len(self.model.decoder.layers)
+        layer_ipu = get_layer_ipu(self.ipu_config.layers_per_ipu, number_of_layers)
         for index, layer in enumerate(self.model.encoder.layers):
             ipu = layer_ipu[index]
             if self.ipu_config.recompute_checkpoint_every_layer and index != self.config.num_hidden_layers - 1:
