@@ -301,7 +301,6 @@ class DebertaPipelineMixin(PipelineMixin):
         - Adds recomputation checkpoints
         """
         self._hooks = []
-        layer_ipu = get_layer_ipu(self.ipu_config.layers_per_ipu)
 
         logger.info("-------------------- Device Allocation --------------------")
         logger.info("Embedding  --> IPU 0")
@@ -332,6 +331,7 @@ class DebertaPipelineMixin(PipelineMixin):
         if self.deberta.encoder.relative_attention:
             self.deberta.encoder.rel_embeddings = poptorch.BeginBlock(self.deberta.encoder.rel_embeddings, ipu_id=0)
 
+        layer_ipu = get_layer_ipu(self.ipu_config.layers_per_ipu, self.deberta.encoder.layer)
         for index, layer in enumerate(self.deberta.encoder.layer):
             ipu = layer_ipu[index]
             if self.ipu_config.recompute_checkpoint_every_layer and index != self.config.num_hidden_layers - 1:
