@@ -67,8 +67,6 @@ class GPT2PipelineMixin(PipelineMixin):
                 self.transformer.wte, self.ipu_config.embedding_serialization_factor
             )
 
-        layer_ipu = get_layer_ipu(self.ipu_config.layers_per_ipu)
-
         logger.info("-------------------- Device Allocation --------------------")
         logger.info("Embedding  --> IPU 0")
         self.transformer.wte = poptorch.BeginBlock(self.transformer.wte, "Token embedding", ipu_id=0)
@@ -76,6 +74,7 @@ class GPT2PipelineMixin(PipelineMixin):
         hs = outline_attribute(self.transformer.ln_f, "LayerNorm")
         self._hooks.extend(hs)
 
+        layer_ipu = get_layer_ipu(self.ipu_config.layers_per_ipu, self.transformer.h)
         for index, layer in enumerate(self.transformer.h):
             ipu = layer_ipu[index]
             if self.ipu_config.recompute_checkpoint_every_layer and index != self.config.num_hidden_layers - 1:
@@ -148,8 +147,6 @@ class PipelinedGPT2LMHeadModel(GPT2LMHeadModel, PipelineMixin):
             self.lm_head = serialized_lm_head
             self.tie_weights()
 
-        layer_ipu = get_layer_ipu(self.ipu_config.layers_per_ipu)
-
         logger.info("-------------------- Device Allocation --------------------")
         logger.info("Token Embedding     --> IPU 0")
         self.transformer.wte = poptorch.BeginBlock(self.transformer.wte, "Token embedding", ipu_id=0)
@@ -158,6 +155,7 @@ class PipelinedGPT2LMHeadModel(GPT2LMHeadModel, PipelineMixin):
         hs = outline_attribute(self.transformer.ln_f, "LayerNorm")
         self._hooks.extend(hs)
 
+        layer_ipu = get_layer_ipu(self.ipu_config.layers_per_ipu, self.transformer.h)
         for index, layer in enumerate(self.transformer.h):
             ipu = layer_ipu[index]
             if self.ipu_config.recompute_checkpoint_every_layer:
