@@ -86,11 +86,7 @@ class CustomT5Block(T5Block):
         hidden_states, present_key_value_state = self_attention_outputs[:2]
         attention_outputs = self_attention_outputs[2:]  # Keep self-attention outputs and relative position weights
 
-        # clamp inf values to enable fp16 training
-        # Custom: Remove check for inf
-        if hidden_states.dtype == torch.float16:
-            clamp_value = torch.finfo(hidden_states.dtype).max - 1000
-            hidden_states = torch.clamp(hidden_states, min=-clamp_value, max=clamp_value)
+        # Change: Remove check for inf and fp16 clamping
 
         do_cross_attention = self.is_decoder and encoder_hidden_states is not None
         if do_cross_attention:
@@ -114,11 +110,7 @@ class CustomT5Block(T5Block):
             )
             hidden_states = cross_attention_outputs[0]
 
-            # clamp inf values to enable fp16 training
-            # Custom: Remove check for inf
-            if hidden_states.dtype == torch.float16:
-                clamp_value = torch.finfo(hidden_states.dtype).max - 1000
-                hidden_states = torch.clamp(hidden_states, min=-clamp_value, max=clamp_value)
+            # Change: Remove check for inf and fp16 clamping
 
             # Combine self attn and cross attn key value states
             if present_key_value_state is not None:
@@ -130,11 +122,7 @@ class CustomT5Block(T5Block):
         # Apply Feed Forward layer
         hidden_states = self.layer[-1](hidden_states)
 
-        # clamp inf values to enable fp16 training
-        # Custom: Remove check for inf
-        if hidden_states.dtype == torch.float16:
-            clamp_value = torch.finfo(hidden_states.dtype).max - 1000
-            hidden_states = torch.clamp(hidden_states, min=-clamp_value, max=clamp_value)
+        # Change: Remove check for inf and fp16 clamping
 
         outputs = (hidden_states,)
 
@@ -241,7 +229,6 @@ class PipelinedT5ForConditionalGeneration(
         model = PipelinedT5ForConditionalGeneration(config).parallelize().half()
         ```
         """
-        layer_ipu = get_layer_ipu(self.ipu_config.layers_per_ipu)
 
         logger.info("-------------------- Device Allocation --------------------")
         logger.info("Embedding  --> IPU 0")
@@ -274,6 +261,8 @@ class PipelinedT5ForConditionalGeneration(
         for block in self.decoder.block:
             block.__class__ = CustomT5Block
 
+        number_of_layers = len(self.encoder.block) + len(self.decoder.block)
+        layer_ipu = get_layer_ipu(self.ipu_config.layers_per_ipu, number_of_layers)
         for index, layer in enumerate(self.encoder.block):
             ipu = layer_ipu[index]
             if self.ipu_config.recompute_checkpoint_every_layer and index != self.config.num_layers - 1:
